@@ -963,9 +963,10 @@ PHP_FUNCTION(stomp_read_frame)
 				}
 
 				fci.size = sizeof(fci);
+#if (PHP_MAJOR_VERSION == 7 && PHP_MINOR_VERSION == 0)
 				fci.function_table = &ce->function_table;
 				fci.symbol_table = NULL;
-
+#endif
 				/* PARAMS */
 				fci.param_count = 3;
 				fci.params = (zval*) safe_emalloc(sizeof(zval), 3, 0);
@@ -980,7 +981,11 @@ PHP_FUNCTION(stomp_read_frame)
 
 				fcc.initialized = 1;
 				fcc.function_handler = ce->constructor;
+#if (PHP_MAJOR_VERSION == 7 && PHP_MINOR_VERSION == 0)
 				fcc.calling_scope = EG(scope);
+#else
+				fcc.calling_scope = zend_get_executed_scope();
+#endif
 				fcc.object = Z_OBJ_P(return_value);
 
 				if (zend_call_function(&fci, &fcc ) == FAILURE) {
